@@ -169,6 +169,22 @@ class Qimai_Outside_Tool:
                 return True
         return False
 
+    def get_week_day(self):
+        """
+            * 获取今日星期几：
+        """
+        week_day = {
+            0: '星期一',
+            1: '星期二',
+            2: '星期三',
+            3: '星期四',
+            4: '星期五',
+            5: '星期六',
+            6: '星期日',
+        }
+        day = self.data_info[0].weekday()  # weekday()可以获得是星期几
+        return week_day[day]
+
     def json_to_df(self):
         """
             * json转为pandas的表格形式；
@@ -875,7 +891,7 @@ class Get_App_Keyword(Qimai_Diy_Var):
                         return '未覆盖'
                     elif int(i['r']) == 0:
                         # 等于0则需要继续判断
-                        n_keyword_status = Get_App_Keyword(appid).get_match_keywordRank(keyword, start_date, end_date, day)
+                        n_keyword_status = Get_App_Keyword(self.appid).get_match_keywordRank(keyword, start_date, end_date, day)
                         if n_keyword_status == '掉词':
                             return '掉词'
                         else:
